@@ -1,7 +1,7 @@
 import os
 from uuid import uuid4
 
-from lightning import LightningFlow
+from lightning import CloudCompute, LightningFlow
 from lightning.app.components.database import Database, DatabaseClient
 from lightning.app.frontend import StaticWebFrontend
 from lightning.app.storage import Drive
@@ -48,21 +48,26 @@ class TrainingStudio(LightningFlow):
                 DataConfig,
             ]
         )
+        self.db.cloud_compute = CloudCompute("cpu", disk_size=80)
 
-        self.ready = False
+        self.has_setup = False
         self._db_client = None
         self._token = uuid4().hex
         self.seconds = ",".join([str(v) for v in range(0, 60, 1)])
 
+    @property
+    def ready(self) -> bool:
+        return self.db.alive()
+
     def run(self):
         self.db.run(token=self._token)
 
         if not self.db.alive():
             return
 
-        if not self.ready:
+        if not self.has_setup:
             print("The Training Studio App is ready !")
-            self.ready = True
+            self.has_setup = True
 
         # Run every seconds.
         if self.schedule(f"* * * * * {self.seconds}"):
